@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "GxSelector.h"
@@ -148,19 +148,25 @@ static void gx_selector_get_positions(
 
 static void gx_selector_draw_arrow(const GdkRectangle *rect, gint yborder, cairo_t *cr, gboolean has_focus)
 {
-	cairo_rectangle(cr, rect->x, rect->y, rect->width, rect->height);
-	cairo_set_source_rgb(cr, 0, 0, 0);
+	cairo_rectangle(cr, rect->x-1, rect->y, rect->width+1, rect->height-2);
+    cairo_pattern_t*pat =
+		cairo_pattern_create_linear (rect->x-1, rect->y,rect->x+rect->width ,rect->y+ rect->height);
+	cairo_pattern_add_color_stop_rgb (pat, 0, 0.3, 0.3, 0.3);
+	cairo_pattern_add_color_stop_rgb (pat, 1, 0.05, 0.05, 0.05);
+	cairo_set_source (cr, pat);
 	cairo_fill_preserve(cr);
-	cairo_set_line_width(cr, 1.0);
+    cairo_set_line_width(cr, 1.0);
+    cairo_set_source_rgb(cr, 0., 0., 0.);
+    cairo_stroke(cr);
+    cairo_pattern_destroy (pat);
 	if (has_focus) {
-		cairo_move_to(cr, rect->x, rect->y + rect->height - yborder);
-		cairo_line_to(cr, rect->x + rect->width / 2.0, rect->y + yborder);
-		cairo_line_to(cr, rect->x + rect->width, rect->y + rect->height - yborder);
-		cairo_set_source_rgb(cr, 0.3, 0.3, 0.3);
-	} else {
-		cairo_set_source_rgb(cr, 0.2, 0.2, 0.2);
+		cairo_move_to(cr, rect->x, rect->y + rect->height - 1 - yborder);
+		cairo_line_to(cr, rect->x + rect->width / 2.0, rect->y - 1 + yborder);
+		cairo_line_to(cr, rect->x + rect->width, rect->y + rect->height - 1 - yborder);
+        cairo_line_to(cr,rect->x, rect->y + rect->height - 1 - yborder);
+		cairo_set_source_rgb(cr, 0.6, 0.6, 0.6);
+        cairo_fill(cr);
 	}
-	cairo_stroke (cr);
 }
 
 static gboolean gx_selector_expose (GtkWidget *widget, GdkEventExpose *event)
@@ -192,7 +198,7 @@ static gboolean gx_selector_expose (GtkWidget *widget, GdkEventExpose *event)
 		GtkTreeIter iter;
 		gtk_tree_model_iter_nth_child(selector->model, &iter, NULL, selectorstate);
 		gtk_tree_model_get(selector->model, &iter, 0, &s, -1);
-		pango_layout_set_text(layout, _(s), -1);
+		pango_layout_set_text(layout, s, -1);
 		pango_layout_get_pixel_extents(layout, NULL, &logical);
 		x = text.x + off_x + (priv->textsize.width - logical.width) / 2;
 		y = text.y + off_y + (priv->textsize.height- logical.height)/ 2;
@@ -266,7 +272,7 @@ static void gx_selector_size_request(GtkWidget *widget, GtkRequisition *requisit
 			PangoRectangle logical_rect;
 			gchar *s;
 			gtk_tree_model_get(selector->model, &iter, 0, &s, -1);
-			pango_layout_set_text(l, _(s), -1);
+			pango_layout_set_text(l, s, -1);
 			g_free(s);
 			pango_layout_get_pixel_extents(l, NULL, &logical_rect);
 			if (width < logical_rect.width) {
@@ -314,7 +320,7 @@ static void selection_done(GtkMenu *menu, gpointer data)
 	while (found) {
 		gchar *s;
 		gtk_tree_model_get(selector->model, &iter, 0, &s, -1);
-		if (strcmp(label, _(s)) == 0) {
+		if (strcmp(label, s) == 0) {
 			g_free(s);
 			if (n != get_selector_state(selector)) {
 				gtk_range_set_value(GTK_RANGE(selector), n);
@@ -344,7 +350,7 @@ static gboolean gx_selector_value_entry(GxRegler *regler, GdkRectangle *rect, Gd
 		found = gtk_tree_model_get_iter_first(selector->model, &iter);
 		while (found) {
 			gtk_tree_model_get(selector->model, &iter, 0, &s, -1);
-			GtkWidget *item = gtk_menu_item_new_with_label(_(s));
+			GtkWidget *item = gtk_menu_item_new_with_label(s);
 			gtk_menu_append(m, item);
 			gtk_widget_show(item);
 			g_free(s);
