@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <gtk/gtkiconfactory.h>
@@ -50,6 +50,7 @@ static image_entry image_data[] = {
 	{ "rbutton_off", pb_rbutton_off },
 	{ "vslider", pb_vslider },
 	{ "wheel_back", pb_wheel_back },
+    { "wheel_vertical_back", pb_wheel_vertical_back },
 	{ "wheel_fringe", pb_wheel_fringe },
 	{ "wheel_pointer", pb_wheel_pointer },
 	{ "tribe", pb_tribe },
