@@ -12,30 +12,31 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
-#include "controlparameter.h"
-#include "switch.h"
-#include "regler.h"
-#include "knob.h"
 #include "bigknob.h"
+#include "controlparameter.h"
+#include "eqslider.h"
+#include "fastmeter.h"
+#include "hslider.h"
+#include "iredit.h"
+#include "knob.h"
+#include "levelslider.h"
+#include "meterscale.h"
+#include "minislider.h"
+#include "paintbox.h"
+#include "radiobutton.h"
+#include "regler.h"
+#include "selector.h"
+#include "simplevaluedisplay.h"
 #include "smallknob.h"
 #include "smallknobr.h"
-#include "tuner.h"
-#include "fastmeter.h"
-#include "waveview.h"
-#include "selector.h"
+#include "switch.h"
 #include "toggleimage.h"
-#include "iredit.h"
-#include "radiobutton.h"
-#include "wheel.h"
-#include "hslider.h"
-#include "minislider.h"
-#include "vslider.h"
-#include "eqslider.h"
-#include "levelslider.h"
-#include "paintbox.h"
-#include "meterscale.h"
+#include "tuner.h"
 #include "valuedisplay.h"
-#include "simplevaluedisplay.h"
+#include "vslider.h"
+#include "waveview.h"
+#include "wheel.h"
+#include "wheelvertical.h"
 
 extern "C"
 {
@@ -65,6 +66,7 @@ GType gx_vslider_get_type(void);
 GType gx_value_display_get_type(void);
 GType gx_wave_view_get_type(void);
 GType gx_wheel_get_type(void);
+GType gx_wheel_vertical_get_type(void);
 
 //Declarations of the *_error_quark() functions:
 
@@ -96,6 +98,7 @@ namespace Gxw {  class VSlider_Class { public: static Glib::ObjectBase* wrap_new
 namespace Gxw {  class ValueDisplay_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gxw {  class WaveView_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gxw {  class Wheel_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gxw {  class WheelVertical_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 
 namespace Gxw { 
 
@@ -127,6 +130,7 @@ void wrap_init()
   Glib::wrap_register(gx_value_display_get_type(), &Gxw::ValueDisplay_Class::wrap_new);
   Glib::wrap_register(gx_wave_view_get_type(), &Gxw::WaveView_Class::wrap_new);
   Glib::wrap_register(gx_wheel_get_type(), &Gxw::Wheel_Class::wrap_new);
+  Glib::wrap_register(gx_wheel_vertical_get_type(), &Gxw::WheelVertical_Class::wrap_new);
 
   // Register the gtkmm gtypes:
   Gxw::BigKnob::get_type();
@@ -152,6 +156,7 @@ void wrap_init()
   Gxw::ValueDisplay::get_type();
   Gxw::WaveView::get_type();
   Gxw::Wheel::get_type();
+  Gxw::WheelVertical::get_type();
 
 } // wrap_init()
 
