@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2009, 2010 Hermann Meyer, James Warden, Andreas Degert
+ * Copyright (C) 2011 Pete Shorthose
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  * ---------------------------------------------------------------------------
  *
  *    This is the 6V6 tube table
@@ -22,9 +23,9 @@
  * ----------------------------------------------------------------------------
  */
 
-struct tabled tubetable2[] = {
+table1d_imp<2001> tubetable_6V6[2] = {
 	{ // Ri = 68k
-	-5,5,200, {
+	-5,5,200,2001, {
 	239.919843376,239.854937108,239.789738489,239.724247218,239.658462996,
 	239.592385535,239.526014546,239.459349752,239.392390878,239.325137654,
 	239.257589818,239.189747112,239.121609284,239.053176087,238.984447281,
@@ -428,7 +429,7 @@ struct tabled tubetable2[] = {
 	40.0970179046
 	}},
 	{ // Ri = 250k
-	-5,5,200, {
+	-5,5,200,2001, {
 	239.919843376,239.854937108,239.789738489,239.724247218,239.658462996,
 	239.592385535,239.526014546,239.459349752,239.392390878,239.325137654,
 	239.257589818,239.189747112,239.121609284,239.053176087,238.984447281,
