@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2009, 2010 Hermann Meyer, James Warden, Andreas Degert
+ * Copyright (C) 2011 Pete Shorthose
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  * --------------------------------------------------------------------------
  *
  *
@@ -28,29 +29,23 @@
 
 #pragma once
 
-/* system header files */
-#include <boost/format.hpp>
+#ifndef SRC_HEADERS_GUITARIX_H_
+#define SRC_HEADERS_GUITARIX_H_
 
-/* waf generated defines */
-#include "config.h"
+#include <gtk/gtk.h>
+#include <gtkmm.h>
 
-using namespace std;
+#include "engine.h"
 
-/* guitarix declarations */
-#include "gx_globals.h"
-#include "gx_system.h"
-#include "gx_jack.h"
-#include "gx_child_process.h"
-#include "gx_sndfile.h"
-#include "gx_ui.h"
-#include "gx_convolver.h"
-#include "gx_pitch_tracker.h"
-#include "gx_resampler.h"
-#include "gx_engine.h"
-#include "gx_parameter.h"
-#include "gx_preset.h"
-#include "gx_jconv_settings.h"
-#include "gx_threads.h"
 #include "gx_cairo_callbacks.h"
+
+#include "gx_threads.h"
 #include "gx_gui_helpers.h"
+#include "gx_jconv_settings.h"
+#include "gx_portmap.h"
+#include "gx_main_midi.h"
+#include "gx_main_boxes.h"
+#include "gx_child_process.h"
 #include "gx_main_interface.h"
+
+#endif  // SRC_HEADERS_GUITARIX_H_
